@@ -23,6 +23,20 @@ class Gallery(DeeplabelBase):
     title: str
     parent_folder_id: Optional[str]
 
+    @classmethod
+    def create(
+        cls,
+        project_id: str,
+        title: str,
+        client: "deeplabel.client.BaseClient",
+    )-> "Gallery":
+        json = {
+                "projectId": project_id,
+                "title": title,
+            }
+        resp = client.post('/gallery', json=json)
+        return resp.json()['data']['galleryId']
+
     @classmethod
     def from_search_params(
         cls, params: Dict[str, Any], client: "deeplabel.client.BaseClient"
